@@ -3,9 +3,16 @@ from __future__ import unicode_literals
 
 import os
 
+from django.conf import settings
 from django.template import loader
 from django.template import Context
 from django.contrib.staticfiles import finders
+from django.views.debug import get_safe_settings
+
+try:
+    from collections import OrderedDict
+except ImportError:
+    from django.utils.datastructures import SortedDict as OrderedDict
 
 
 def render_sql_panel(panel, request):
@@ -28,6 +35,12 @@ def render_sql_panel(panel, request):
     # Panel data
     data.update(panel.get_stats())
 
+    # Settings
+    data.update({
+        'settings_title': '<code>%s</code>' % settings.SETTINGS_MODULE,
+        'settings': OrderedDict(sorted(
+            get_safe_settings().items(), key=lambda s: s[0]))})
+
     c = Context(data)
     rendered = t.render(c)
     return rendered
